@@ -7,8 +7,8 @@ from ._bind import CJpegLib
 class version:
     """Class grouping functions for controlling libjpeg method."""
 
-    @staticmethod
-    def set(version: str):
+    @classmethod
+    def set(cls, version: str):
         """Sets the version of libjpeg to use. Loads the library.
 
         :param version: libjpeg version, one of 6b, 8d, 9d, turbo210.
@@ -20,24 +20,27 @@ class version:
         >>> import jpeglib
         >>> jpeglib.version.set('8d')
         """
-        # libjpeg
-        if version in {
-            '6b', '7', '8', '8a', '8b', '8c', '8d', '9', '9a', '9b', '9c', '9d', '9e'
-        }:
-            CJpegLib.set_version(version=version)
-        # libjpeg-turbo
-        elif version in {
-            'turbo120', 'turbo130', 'turbo140', 'turbo150', 'turbo200', 'turbo210'
-        }:
-            CJpegLib.set_version(version=version)
-        # mozjpeg
-        elif version in {
-            'mozjpeg101', 'mozjpeg201', 'mozjpeg300', 'mozjpeg403'
-        }:
-            CJpegLib.set_version(version=version)
-        else:
-            raise NotImplementedError(
-                f'Unsupported libjpeg version: {version}')
+        try:
+            # libjpeg
+            if version in {
+                '6b', '7', '8', '8a', '8b', '8c', '8d', '9', '9a', '9b', '9c', '9d', '9e'
+            }:
+                CJpegLib.set_version(version=version)
+            # libjpeg-turbo
+            elif version in {
+                'turbo120', 'turbo130', 'turbo140', 'turbo150', 'turbo200', 'turbo210'
+            }:
+                CJpegLib.set_version(version=version)
+            # mozjpeg
+            elif version in {
+                'mozjpeg101', 'mozjpeg201', 'mozjpeg300', 'mozjpeg403'
+            }:
+                CJpegLib.set_version(version=version)
+            else:
+                raise NotImplementedError(
+                    f'Unsupported libjpeg version: {version}')
+        except RuntimeError:
+            raise RuntimeError(f'version "{version}" not found, was the package compiled correctly?')
 
     @staticmethod
     def get() -> str:
