@@ -127,7 +127,7 @@ class TestDCT(unittest.TestCase):
     @parameterized.expand([
         ['6b', '7', True],
         ['9d', '9e', True],
-        ['mozjpeg201','mozjpeg300', False],
+        ['mozjpeg201', 'mozjpeg300', False],
     ])
     def test_mismatch_baseline(self, v1, v2, equal_Y):
         """Compress with given two versions and observe differing output."""
@@ -145,11 +145,11 @@ class TestDCT(unittest.TestCase):
         self.assertFalse((Cr1 == Cr2).all())
 
     @parameterized.expand([
-        ['6b','turbo120','turbo130','turbo140','turbo150','turbo200','turbo210'],
-        ['7','8','8a','8b','8c','8d','9','9a','9b','9c','9d'],
+        ['6b', 'turbo120', 'turbo130', 'turbo140', 'turbo150', 'turbo200', 'turbo210'],
+        ['7', '8', '8a', '8b', '8c', '8d', '9', '9a', '9b', '9c', '9d'],
         ['9e'],
-        ['mozjpeg101','mozjpeg201'],
-        ['mozjpeg300','mozjpeg403'],
+        ['mozjpeg101', 'mozjpeg201'],
+        ['mozjpeg300', 'mozjpeg403'],
     ], name_func=version_cluster)
     def test_equal_baseline(self, *versions):
         """Compress with given versions and observe the same output."""
@@ -166,7 +166,7 @@ class TestDCT(unittest.TestCase):
             np.testing.assert_array_equal(qt_ref, qt)
 
     def test_dct_coefficient_decoder(self):
-        """Test output against blorch/dct-coefficient-decoder."""
+        """Test output against btlorch/dct-coefficient-decoder."""
         self.logger.info("test_dct_coefficient_decoder")
         # read DCT with jpeglib
         im = jpeglib.read_dct("examples/IMG_0311.jpeg")
@@ -187,16 +187,14 @@ class TestDCT(unittest.TestCase):
         ])
         YT = (
             d.get_dct_coefficients(0)
-            .reshape((im.width_in_blocks(0), -1, 8, 8), order='F')
-            .transpose((1, 0, 2, 3)))
+            .reshape((im.height_in_blocks(0), im.width_in_blocks(0), 8, 8)))
         CbT = (
             d.get_dct_coefficients(1)
-            .reshape((im.width_in_blocks(1), -1, 8, 8), order='F')
-            .transpose((1, 0, 2, 3)))
+            .reshape((im.height_in_blocks(1), im.width_in_blocks(1), 8, 8)))
         CrT = (
             d.get_dct_coefficients(2)
-            .reshape((im.width_in_blocks(2), -1, 8, 8), order='F')
-            .transpose((1, 0, 2, 3)))
+            .reshape((im.height_in_blocks(2), im.width_in_blocks(2), 8, 8)))
+
         # test equal
         np.testing.assert_array_equal(im.Y, YT)
         np.testing.assert_array_equal(im.Cb, CbT)
@@ -219,15 +217,15 @@ class TestDCT(unittest.TestCase):
         YT = (
             img['coef_arrays'][0]
             .reshape((im.height_in_blocks(0), 8, -1, 8))
-            .transpose((0, 2, 3, 1)))
+            .transpose((0, 2, 1, 3)))
         CbT = (
             img['coef_arrays'][1]
             .reshape((im.height_in_blocks(1), 8, -1, 8))
-            .transpose((0, 2, 3, 1)))
+            .transpose((0, 2, 1, 3)))
         CrT = (
             img['coef_arrays'][2]
             .reshape((im.height_in_blocks(2), 8, -1, 8))
-            .transpose((0, 2, 3, 1)))
+            .transpose((0, 2, 1, 3)))
         qtT = np.stack([
             img['quant_tables'][0],
             img['quant_tables'][1],
@@ -255,6 +253,7 @@ class TestDCT(unittest.TestCase):
                 f"invalid installation of torchjpeg: {e}"
             )
             return
+
         # convert to the same format and test
         def get_full_shape(c):
             return np.array([
@@ -263,28 +262,28 @@ class TestDCT(unittest.TestCase):
             ])
         np.testing.assert_array_equal(
             get_full_shape(jpeg.Y),
-            shape.numpy()[0,::]
+            shape.numpy()[0]
         )
         np.testing.assert_array_equal(
             get_full_shape(jpeg.Cb),
-            shape.numpy()[1,::]
+            shape.numpy()[1]
         )
         np.testing.assert_array_equal(
             get_full_shape(jpeg.Cr),
-            shape.numpy()[2,::]
+            shape.numpy()[2]
         )
         np.testing.assert_array_equal(jpeg.qt, qt.numpy())
         np.testing.assert_array_equal(
             jpeg.Y,
-            np.einsum('abcde->bced', Y.numpy())
+            Y.numpy()[0]
         )  # noqa: E501
         np.testing.assert_array_equal(  # noqa: E501
             jpeg.Cb,
-            np.einsum('bcde->bced', CbCr[0].numpy())
+            CbCr[0].numpy()
         )
         np.testing.assert_array_equal(  # noqa: E501
             jpeg.Cr,
-            np.einsum('bcde->bced', CbCr[1].numpy())
+            CbCr[1].numpy()
         )
 
     def test_pil_qt(self):
@@ -363,7 +362,7 @@ class TestDCT(unittest.TestCase):
         jpeg.write_dct(self.tmp.name)
         jpeg2 = jpeglib.read_dct(self.tmp.name)
         # test matrix
-        self.assertEqual(np.sum(jpeg2.Y - Yc), 1) # difference by 1
+        self.assertEqual(np.sum(jpeg2.Y - Yc), 1)  # difference by 1
         self.assertEqual(
             tuple([int(i) for i in np.where(jpeg2.Y != Yc)]),
             (0, 0, 0, 1)
@@ -404,7 +403,7 @@ class TestDCT(unittest.TestCase):
             Cb=Cb,
             Cr=Cr,
             qt=qt,
-            quant_tbl_no=np.array([0,1,2]),
+            quant_tbl_no=np.array([0, 1, 2]),
         ).write_dct(self.tmp.name)
         # load and compare
         jpeg = jpeglib.read_dct(self.tmp.name)
@@ -413,8 +412,6 @@ class TestDCT(unittest.TestCase):
         np.testing.assert_array_equal(Cr, jpeg.Cr)
         np.testing.assert_array_equal(qt, jpeg.qt)
 
-
-
     # === tests with non-public software ===
     def test_rainer_MMSec(self):
         """Test output against Rainer's MMSec library."""
@@ -438,14 +435,17 @@ class TestDCT(unittest.TestCase):
 
                 # test DCT
                 res = subprocess.call(
-                        ["Rscript", "tests/test_rainer.R",  # script
+                    [
+                        "Rscript", "tests/test_rainer.R",  # script
                         "dct",  # mode - quantization table or DCT coefficients
                         channel,  # channel - Y, Cr, or Cb
                         "examples/IMG_0791.jpeg ",  # input file
-                        self.tmp.name],  # output file
+                        self.tmp.name,  # output file
+                    ],
                     shell=True,
                     stdout=subprocess.DEVNULL,
-                    stderr=subprocess.DEVNULL)
+                    stderr=subprocess.DEVNULL
+                )
                 if res != 0:
                     raise Exception("Rainer's MMSec failed!")
                 df = pd.read_csv(self.tmp.name, header=None)
@@ -460,13 +460,15 @@ class TestDCT(unittest.TestCase):
 
                 # test QT
                 res = subprocess.call(
-                        "Rscript tests/test_rainer.R " + # script
-                        "qt " + " " + # produce quantization table
-                        channel + " " +# Y, Cr or Cb
-                        "examples/IMG_0791.jpeg " + # input file
-                        self.tmp.name, # output file
-
-                    shell=True)
+                    [
+                        "Rscript", "tests/test_rainer.R",  # script
+                        "qt",  # produce quantization table
+                        channel,  # Y, Cr or Cb
+                        "examples/IMG_0791.jpeg",  # input file
+                        self.tmp.name,  # output file
+                    ],
+                    shell=True
+                )
                 if res != 0:
                     raise Exception("Rainer's script failed!")
                 df = pd.read_csv("tmp/result.csv", header=None)
